Circuit Node.js SDK
===================

[![GitHub release](https://img.shields.io/github/release/circuit/circuit-node-sdk.svg)](https://github.com/circuit/circuit-node-sdk)
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)

> For Browser JS SDK see [circuit-js-sdk](https://github.com/circuit/circuit-js-sdk)


### Prerequisites
* [Node v4+](https://nodejs.org/en/download/)
* Developer account on circuitsandbox.net. Get it for free at [developer registration](https://www.circuit.com/web/developers/registration).
* OAuth 2.0 `client_id` and `client_secret`. Get if for free at [circuit.github.com/oauth](https://circuit.github.com/oauth).


### API Reference
https://circuitsandbox.net/sdk/ with most APIs described in the [Client](https://circuitsandbox.net/sdk/classes/Client.html) class. First party webrtc APIs such as `makeCall` are not supported on the Node.js SDK.

More info at [circuit.github.io](https://circuit.github.io/).


### Usage

```bash
npm install --save circuit-node-sdk
```

The Node.js SDK is usually used in two types of applications:
1. **Bots** using OAuth 2.0 Client Credentials grant. Authenticate using `client_id` and `client_secret`. E.g. [xlator-bot](https://github.com/circuit/xlator-bot) or [node-sdk-example](https://github.com/circuit/node-sdk-example)
2. **Server-side web applications** using OAuth 2.0 Authorization Grant. Authentication and token management done on the server. Logon via Node.JS SDK using `client_id` and `access token`. E.g. [node-linkify](https://github.com/circuit/node-linkify) or [circuit-google-assistant](https://github.com/circuit/circuit-google-assistant)


### Examples
Here is a short example to get the idea. More complete examples on [github](https://github.com/circuit).

```javascript
// Create Circuit client instance for OAuth 2.0 (Client Credentials Grant) on the sandbox system
const Circuit = require('circuit-node-sdk')
const client = new Circuit.Client({
  client_id: '<client_id>',
  client_secret: '<client_secret>',
  domain: 'circuitsandbox.net'
});

// Register and log all events
Circuit.supportedEvents.forEach(e => client.addEventListener(e, console.log));

// Logon, then create a group conversation with two users and send a text message
client.logon()
  .then(user => console.log(`Logged on as ${user.displayName}`, user))
  .then(() => client.getUsersByEmail(['kim.jackson@mailinator.com', 'maeva.barnaby@mailinator.com']))
  .then(users => users.map(user => user.userId))
  .then(userIds => client.createGroupConversation(userIds, 'runkit example'))
  .then(conv => client.addTextItem(conv.convId, 'I am test bot. What can I do for you?'))
  .then(client.logout)
  .catch(console.error)
```
> [Try it on runkit](https://runkit.com/rogeru/circuit-node-sdk)


### Help us improve the SDK
Help us improve the SDK or examples by sending us a pull-request or opening a [GitHub Issue](https://github.com/circuit/circuit-node-sdk/issues/new).
